==> gahgu133plus2_1.4.0.tar.gz: gahgu133plus2/man/gahgu133plus2GO.Rd <==
\name{gahgu133plus2GO}
\alias{gahgu133plus2GO}
\title{Map between custom probeset IDs and Gene Ontology (GO)}
\description{
  gahgu133plus2GO is an R environment that provides mappings between
  custom probeset identifiers and the GO identifiers that they are
  directly associated with.
}
\details{
     Each custom probeset identifier is mapped to a list of lists.  The names on
     the outer list are GO identifiers.  Each inner list contains of five
     named elements: GOID, Ontology, Term, Evidence and PMIDS.

     The GOID element matches the GO identifier named in the outer list.

     The Ontology element indicates which of the three Gene Ontology
     categories this identifier belongs to.  The categories are
     biological process (BP), cellular component (CC), and molecular
     function (MF).

     The Term element indicates the name of GO cathegory correspoding to the
     GO identifier named in the outer list.

     The Evidence element contains a code indicating what kind of
     evidence supports the association of the GO identifier to the Entrez Gene
     id. The evidence codes in use include:

  IMP: inferred from mutant phenotype  

  IGI: inferred from genetic interaction

  IPI: inferred from physical interaction  

  ISS: inferred from sequence similarity 

  IDA: inferred from direct assay  

  IEP: inferred from expression pattern  

  IEA: inferred from electronic annotation  

  TAS: traceable author statement  

  NAS: non-traceable author statement  

  ND: no biological data available  

  IC: inferred by curator

  The PMIDS element indicates the Pubmed IDs of references in the literature, if relevant,
  obtained from EntrezGene.

  NAs are assigned to probe identifiers that can not be mapped to any Gene Ontology
  information. Other information concerning Gene Ontology classification are available
  in a separate data package named GO.


  Mappings were based on data provided by:

  GeneCards database - www.genecards.org

  Package built Mon Feb 25 23:53:26 2008
}
\references{
  \url{www.genecards.org}
}
\examples{
    # Convert to a list
    xx <- as.list(gahgu133plus2GO)
    # Remove all the NAs
    xx <- xx[!is.na(xx)]
    if(length(xx) > 0){
            # Try the first one
            got <- xx[[1]]           
            got[[1]][["GOID"]]
            got[[1]][["Ontology"]]
            got[[1]][["Evidence"]]

    }
}
\keyword{datasets}

==> gahgu133plus2_1.4.5.tar.gz: gahgu133plus2/man/gahgu133plus2GO.Rd <==
\name{gahgu133plus2GO}
\alias{gahgu133plus2GO}
\title{Map between custom probeset IDs and Gene Ontology (GO)}
\description{
  gahgu133plus2GO is an R environment that provides mappings between
  custom probeset identifiers and the GO identifiers that they are
  directly associated with.
}
\details{
     Each custom probeset identifier is mapped to a list of lists.  The names on
     the outer list are GO identifiers.  Each inner list contains of five
     named elements: GOID, Ontology, Term, Evidence and PMIDS.

     The GOID element matches the GO identifier named in the outer list.

     The Ontology element indicates which of the three Gene Ontology
     categories this identifier belongs to.  The categories are
     biological process (BP), cellular component (CC), and molecular
     function (MF).

     The Term element indicates the name of GO cathegory correspoding to the
     GO identifier named in the outer list.

     The Evidence element contains a code indicating what kind of
     evidence supports the association of the GO identifier to the Entrez Gene
     id. The evidence codes in use include:

  IMP: inferred from mutant phenotype  

  IGI: inferred from genetic interaction

  IPI: inferred from physical interaction  

  ISS: inferred from sequence similarity 

  IDA: inferred from direct assay  

  IEP: inferred from expression pattern  

  IEA: inferred from electronic annotation  

  TAS: traceable author statement  

  NAS: non-traceable author statement  

  ND: no biological data available  

  IC: inferred by curator

  The PMIDS element indicates the Pubmed IDs of references in the literature, if relevant,
  obtained from EntrezGene.

  NAs are assigned to probe identifiers that can not be mapped to any Gene Ontology
  information. Other information concerning Gene Ontology classification are available
  in a separate data package named GO.


  Mappings were based on data provided by:

  GeneCards database - www.genecards.org

  Package built Mon Aug 25 17:35:47 2008
}
\references{
  \url{www.genecards.org}
}
\examples{
    # Convert to a list
    xx <- as.list(gahgu133plus2GO)
    # Remove all the NAs
    xx <- xx[!is.na(xx)]
    if(length(xx) > 0){
            # Try the first one
            got <- xx[[1]]           
            got[[1]][["GOID"]]
            got[[1]][["Ontology"]]
            got[[1]][["Evidence"]]

    }
}
\keyword{datasets}
